﻿namespace TestBed
{
   using System;
   using System.Collections.Generic;
   using Telerik.WinControls.UI;
   using Telerik.WinControls.UI.Scheduler.ICalendar;

   public class SchedulerICalendarImporter2 : SchedulerICalendarImporter
   {
      private SchedulerResourceCollection m_Resources;

      public SchedulerICalendarImporter2(SchedulerResourceCollection resources)
         : base()
      {
         m_Resources = resources;
      }

      /// <summary>
      /// Remove duplicates based on UniqueId
      /// </summary>
      /// <exception cref="CalendarParseException"><c>CalendarParseException</c>.</exception>
      protected override void GetAppointments(CalObject calendar, ICollection<IEvent> collection)
      {
         base.GetAppointments(calendar, collection);

         Dictionary<EventId, IEvent> dictionary = new Dictionary<EventId, IEvent>();
         foreach (IEvent ievent in collection)
         {
            dictionary[ievent.UniqueId] = ievent;
         }

         collection.Clear();
         foreach (IEvent iEvent in dictionary.Values)
            collection.Add(iEvent);
      }

      /// <summary>
      /// Writes the additional data for appointment.
      /// </summary>
      /// <param name="appointment">The appointment.</param>
      /// <param name="calObject">The cal object.</param>
      protected override void ApplyAdditionalData(IEvent appointment, CalObject calObject)
      {
         base.ApplyAdditionalData(appointment, calObject);

         CalProperty prop = calObject["RESOURCES"];
         if (prop != null)
         {
            AddResourceIds(prop, appointment);
         }
      }

      private void AddResourceIds(CalProperty prop, IEvent appointment)
      {
         string[] resources = CalProperty.ToText(prop).Split(new[] { ';', ',' }, StringSplitOptions.RemoveEmptyEntries);

         foreach (string resource in resources)
         {
            if (m_Resources.GetById(resource) == null)
               m_Resources.Add(new Resource(resource, resource));
            appointment.ResourceIds.Add(new EventId(resource));
         }
      }
   }
}
